@@ -6,7 +6,7 @@ the Software are granted under this license.
 
 The Clear BSD License
 
-Copyright (c) 2019-2024, Fraunhofer-Gesellschaft zur Förderung der angewandten Forschung e.V. & The VVenC Authors.
+Copyright (c) 2019-2026, Fraunhofer-Gesellschaft zur Förderung der angewandten Forschung e.V. & The VVenC Authors.
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification,
@@ -109,14 +109,9 @@ public:
   unsigned        maxLastPosY     ()                        const { return m_maxLastPosY; }
   unsigned        lastXCtxId      ( unsigned  posLastX  )   const { return m_CtxSetLastX( m_lastOffsetX + ( posLastX >> m_lastShiftX ) ); }
   unsigned        lastYCtxId      ( unsigned  posLastY  )   const { return m_CtxSetLastY( m_lastOffsetY + ( posLastY >> m_lastShiftY ) ); }
-  int             numCtxBins      ()                        const { return   m_remainingContextBins;      }
-  void            setNumCtxBins   ( int n )                       {          m_remainingContextBins  = n; }
   unsigned        sigGroupCtxId   ( bool ts = false     )   const { return ts ? m_sigGroupCtxIdTS : m_sigGroupCtxId; }
   bool            bdpcm           ()                        const { return m_bdpcm; }
 
-  void            decimateNumCtxBins(int n) { m_remainingContextBins -= n; }
-  void            increaseNumCtxBins(int n) { m_remainingContextBins += n; }
-
   unsigned sigCtxIdAbs( int scanPos, const TCoeffSig* coeff, const int state )
   {
     const uint32_t   posY      = m_scan[scanPos].y;
@@ -427,12 +422,12 @@ public:
     return(absCoeffMod);
   }
 
-  unsigned templateAbsSumTS( int scanPos, const TCoeffSig* coeff )
-  {
-    return 1;
-  }
+  //unsigned templateAbsSumTS( int scanPos, const TCoeffSig* coeff )
+  //{
+  //  return 1;
+  //}
 
-  int                       regBinLimit;
+  int                       remRegBins;
 
 private:
   // constant
@@ -481,7 +476,6 @@ private:
   CtxSet                    m_tsGtxFlagCtxSet;
   CtxSet                    m_tsLrg1FlagCtxSet;
   CtxSet                    m_tsSignFlagCtxSet;
-  int                       m_remainingContextBins;
   std::bitset<MLS_GRP_NUM>  m_sigCoeffGroupFlag;
   const bool                m_bdpcm;
   CtxTpl*                   m_tplBuf;
